Documentation
¶
Index ¶
- Variables
- func Get() models.Config
- func Init()
- func Initialize(path string) error
- func OverrideAlloyConfig(overrides models.AlloyConfig)
- func OverrideBlockNodeConfig(overrides models.BlockNodeConfig)
- func OverrideTeleportConfig(overrides models.TeleportConfig)
- func ServiceAccount() security.ServiceAccount
- func Set(c *models.Config) error
- func SetProfile(profile string)
Constants ¶
This section is empty.
Variables ¶
var ( ErrNamespace = errorx.NewNamespace("config") NotFoundError = ErrNamespace.NewType("not_found", errorx.NotFound()) )
Functions ¶
func Initialize ¶
Initialize loads the configuration from the specified file.
Parameters:
- path: The path to the configuration file.
Returns:
- An error if the configuration cannot be loaded.
func OverrideAlloyConfig ¶
func OverrideAlloyConfig(overrides models.AlloyConfig)
OverrideAlloyConfig updates the Alloy configuration with provided overrides. Empty string values are ignored (not applied). Remote arrays are always replaced (declarative semantics) - pass empty arrays to clear remotes. Note: Passwords are managed via Vault and External Secrets Operator.
func OverrideBlockNodeConfig ¶
func OverrideBlockNodeConfig(overrides models.BlockNodeConfig)
OverrideBlockNodeConfig updates the block node configuration with provided overrides. Empty string values are ignored (not applied).
func OverrideTeleportConfig ¶
func OverrideTeleportConfig(overrides models.TeleportConfig)
OverrideTeleportConfig updates the Teleport configuration with provided overrides. Empty string values are ignored (not applied).
func ServiceAccount ¶
func ServiceAccount() security.ServiceAccount
func SetProfile ¶
func SetProfile(profile string)
SetProfile sets the active profile in the global configuration.
Types ¶
This section is empty.